indoorSound15 = {};

function indoorSound15.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Motorized, specializations);
end;

function indoorSound15:load(xmlFile)
	self.swapSounds = SpecializationUtil.callSpecializationsFunction("swapSounds");

	self.stopSoundsOn = true;	-- set this to false if the normal motor sounds should be played while threshing
	self.soundSwitched = false;
	self.internalSoundFactor = 0.3;
	
	self.StartSoundInside = Utils.loadSample(xmlFile, {}, "vehicle.StartSoundInside", nil, self.baseDirectory, self.components[1].node);
	self.SoundInside = Utils.loadSample(xmlFile, {}, "vehicle.SoundInside", nil, self.baseDirectory, self.components[1].node);
	self.StopSoundInside = Utils.loadSample(xmlFile, {}, "vehicle.StopSoundInside", nil, self.baseDirectory, self.components[1].node);
	self.StartSoundOutside = Utils.loadSample(xmlFile, {}, "vehicle.StartSound", nil, self.baseDirectory, self.components[1].node);
	self.SoundOutside = Utils.loadSample(xmlFile, {}, "vehicle.Sound", nil, self.baseDirectory, self.components[1].node);
	self.StopSoundOutside = Utils.loadSample(xmlFile, {}, "vehicle.StopSound", nil, self.baseDirectory, self.components[1].node);
end;

function indoorSound15:delete()
end;

function indoorSound15:mouseEvent(posX, posY, isDown, isUp, button)
end;

function indoorSound15:keyEvent(unicode, sym, modifier, isDown)
end;

function indoorSound15:update(dt)
	if self.isEntered then
		if g_currentMission.driveControl ~= nil and g_currentMission.driveControl.useModules.inDoorSound then
			g_currentMission.driveControl.useModules.inDoorSound = false;
		end;
		
		if self:getIsActiveForSound() then
			if self.sampleMotor ~= nil then
				local samples = {self.sampleMotor, self.sampleMotorRun, self.sampleMotorStart, self.sampleMotorStop, self.sampleHonk, self.sampleRefuel, self.sampleReverseDrive, self.sampleCompression, self.sampleHydraulic, self.sampleCompressedAir, self.sampleCylinderedHydraulic};
				for _,sample in pairs(samples) do
					if sample ~= nil then
						local targetVolume = sample.volume;
						if self.cameras[self.camIndex].isInside then
							targetVolume = self.internalSoundFactor*targetVolume;
						end;
						if sample.sample ~= nil then
							setSampleVolume(sample.sample,targetVolume);
						end;
					end;
				end;
			end;
		end;
	end;
	if self:getIsActive() then
		if self.stopSoundsOnThreshing then
			if Utils.isSamplePlaying(self.sample) then
				Utils.stopSample(self.sampleMotor, true);
				Utils.stopSample(self.sampleMotorRun, true);
				Utils.stop3DSample(self.sampleMotor, true);
				Utils.stop3DSample(self.sampleMotorRun, true);
			else
				if self.isMotorStarted and self.isEntered then
					if not Utils.isSamplePlaying(self.sampleMotorStart) and (not Utils.isSamplePlaying(self.sampleMotor) or not Utils.isSamplePlaying(self.sampleMotorRun)) then
						Utils.playSample(self.sampleMotor, 0, 0, nil);
						Utils.playSample(self.sampleMotorRun, 0, 0, 0);
					end;
				end;
			end;
		end;
		if (self.cameras[self.camIndex].isInside) and (not self.soundSwitched) and (self.isEntered) then
			self:swapSounds("inside");
			self.soundSwitched = true;
		elseif (not self.cameras[self.camIndex].isInside and self.soundSwitched) or (self.isEntered == false and self.soundSwitched) then
			self:swapSounds("outside");
			self.soundSwitched = false;
		end;
	end;
end;

function indoorSound15:updateTick(dt)
end;

function indoorSound15:draw()
end;

function indoorSound15:swapSounds(camInOut)
	if Utils.isSamplePlaying(self.sampleThreshing) then
		Utils.stopSample(self.sampleThreshing, true);
	end;

	if camInOut == "outside" then
		self.sampleStart = self.StartSoundOutside;
		self.sampleStop = self.topSoundOutside;
		self.sample = self.SoundOutside;
	elseif camInOut == "inside" then
		self.sampleStart = self.StartSoundInside;
		self.sampleStop = self.StopSoundInside;
		self.sample = self.SoundInside;
	end;
	if g_currentMission.driveControl ~= nil and not g_currentMission.driveControl.useModules.internalSound and self.internalSound.dCwasTurnedOn then
			g_currentMission.driveControl.useModules.internalSound = true;
		end;
	end;